# Mozilla User Preferences

/* Do not edit this file.
 *
 * If you make changes to this file while the application is running,
 * the changes will be overwritten when the application exits.
 *
 * To make a manual change to preferences, you can visit the URL about:config
 */

user_pref("app.update.lastUpdateTime.addon-background-update-timer", 1397513034);
user_pref("app.update.lastUpdateTime.background-update-timer", 0);
user_pref("app.update.lastUpdateTime.blocklist-background-update-timer", 0);
user_pref("app.update.lastUpdateTime.browser-cleanup-thumbnails", 1397512458);
user_pref("app.update.lastUpdateTime.search-engine-update-timer", 1397512578);
user_pref("app.update.silent", true);
user_pref("browser.bookmarks.restore_default_bookmarks", false);
user_pref("browser.cache.disk.capacity", 358400);
user_pref("browser.cache.disk.smart_size.first_run", false);
user_pref("browser.cache.disk.smart_size.use_old_max", false);
user_pref("browser.cache.disk.smart_size_cached_value", 358400);
user_pref("browser.download.panel.firstSessionCompleted", true);
user_pref("browser.migration.version", 13);
user_pref("browser.newtabpage.storageVersion", 1);
user_pref("browser.pagethumbnails.storage_version", 3);
user_pref("browser.places.smartBookmarksVersion", 4);
user_pref("browser.slowStartup.averageTime", 0);
user_pref("browser.slowStartup.samples", 0);
user_pref("browser.startup.homepage_override.buildID", "20140319032835");
user_pref("browser.startup.homepage_override.mstone", "24.4.0");
user_pref("extensions.lastAppVersion", "24.4.0");
user_pref("extensions.lastPlatformVersion", "24.4.0");
user_pref("extensions.pendingOperations", false);
user_pref("extensions.shownSelectionUI", true);
user_pref("extensions.sdk.console.logLevel", "all");
user_pref("general.warnOnAboutConfig", false);
user_pref("intl.charsetmenu.browser.cache", "UTF-8");
user_pref("network.cookie.prefsMigrated", true);
user_pref("pdfjs.migrationVersion", 1);
user_pref("pdfjs.previousHandler.alwaysAskBeforeHandling", true);
user_pref("pdfjs.previousHandler.preferredAction", 4);
user_pref("places.history.expiration.transient_current_max_pages", 104858);
user_pref("plugin.disable_full_page_plugin_for_types", "application/pdf");
user_pref("plugin.importedState", true);
user_pref("plugin.soname.list", "libXt.so:libXext.so");
user_pref("print.always_print_silent", true);
user_pref("print.print_bgcolor", true);
user_pref("print.print_bgimages", true);
user_pref("print.print_colorspace", "default");
user_pref("print.print_downloadfonts", false);
user_pref("print.print_evenpages", true);
user_pref("print.print_footerleft", "");
user_pref("print.print_footerright", "");
user_pref("print.print_headerleft", "");
user_pref("print.print_headerright", "");
user_pref("print.print_in_color", true);
user_pref("print.print_landscape", true);
user_pref("print.print_margin_bottom", "0");
user_pref("print.print_margin_left", "0");
user_pref("print.print_margin_right", "0");
user_pref("print.print_margin_top", "0");
user_pref("print.print_oddpages", true);
user_pref("print.print_orientation", 1);
user_pref("print.print_page_delay", 50);
user_pref("print.print_paper_data", 0);
user_pref("print.print_paper_height", "279.40");
user_pref("print.print_paper_name", "na_letter");
user_pref("print.print_paper_size_type", 1);
user_pref("print.print_paper_size_unit", 1);
user_pref("print.print_paper_width", "215.90");
user_pref("print.print_plex_name", "default");
user_pref("print.print_resolution_name", "default");
user_pref("print.print_scaling", "  1.00");
user_pref("print.print_shrink_to_fit", true);
user_pref("print.print_to_file", true);
user_pref("print.print_to_filename", "%(output_filename)s");
user_pref("print.print_unwriteable_margin_bottom", 0);
user_pref("print.print_unwriteable_margin_left", 0);
user_pref("print.print_unwriteable_margin_right", 0);
user_pref("print.print_unwriteable_margin_top", 0);
user_pref("print_printer", "Print to File");
user_pref("privacy.sanitize.migrateFx3Prefs", true);
user_pref("toolkit.startup.last_success", 1397513678);
user_pref("toolkit.telemetry.previousBuildID", "20140319045509");
user_pref("xpinstall.whitelist.add", "");
user_pref("xpinstall.whitelist.add.180", "");
user_pref("xpinstall.whitelist.add.36", "");
